/*
  merlin_mount.cpp - Arduino library support for Merlin/Orion telescope mounts
  Copyright (c)2009 Gustav Evertsson All right reserved
  www.guzzzt.com - me@guzzzt.com
 
  
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
  Version:   1.0 - Aug 7 2009
  
*/

#include <inttypes.h>
#include "HardwareSerial.h"

#ifndef	MERLIN_MOUNT_H
#define MERLIN_MOUNT_H

#define INIT_SUCCESS 1
#define INIT_FAILED  0

#define AXIS_YAW   1
#define AXIS_PITCH 2

#define DIR_UP    0
#define DIR_DOWN  1
#define DIR_RIGHT 0
#define DIR_LEFT  1
#define DIR_STOPPED 2

#define STATUS_STOPPED 0
#define STATUS_RUNNING 1

#define MOUNT_RX_PIN 0
#define MOUNT_TX_PIN 1

#define SYNC_ASYNCHRONY 0
#define SYNC_SYNCHRONY  1

#define COMPLETE_TURN 943616

#define AXIS_ACCURACY 262 // 0.1 degree


class MerlinMount
{
	private:
		uint8_t initiated;
  public:
	// Handle position value
	  long parsePosVal(char* hexStr);
	  void valToHexStr(long val, char* hexStr);
	  double toAngle(long first, long second);
	  long fromAngle(double angle);
  // Init
    MerlinMount();
    uint8_t init();
  // Control functions
    void startMoving(uint8_t axis, uint8_t dir);
    void stopMoving(uint8_t axis);
    void driveToPosition(uint8_t axis, long position);
    void driveToPositionBothAxis(long positionYaw, long positionPitch, uint8_t sync);
  // Camera functions
  	void takePicture(int shutterTime);
  	
	// Status functions
		long readAxisPosition(uint8_t axis);
		uint8_t readAxisStatus(uint8_t axis);
	
	// Communication with the Merlin mount
		void sendCommand(const char* send, char* respose);
};

extern MerlinMount merlin;
#endif
